#include "Touch.h"

Touch::Touch(SDL_Surface* pScreen)
   : m_pScreen(pScreen)
{
   m_ptad_info = touchpad_getinfo();
   m_pFont = nSDL_LoadFont(NSDL_FONT_THIN, 0, 0, 0);
}

Touch::~Touch()
{
   nSDL_FreeFont(m_pFont);
}

bool Touch::Loop()
{
   //Handle keypresses
   if( PollEvents() == false )
      return false;

   touchpad_scan(&m_tpad_report);

   UpdateDisplay();

   return true;
}

bool Touch::PollEvents()
{
   SDL_Event event;

   /* Poll for events. SDL_PollEvent() returns 0 when there are no  */
   /* more events on the event queue, our while loop will exit when */
   /* that occurs.                                                  */
   while( SDL_PollEvent( &event ) )
   {
      /* We are only worried about SDL_KEYDOWN and SDL_KEYUP events */
      switch( event.type )
      {
      case SDL_KEYDOWN:
         printf( "Key press detected\n" );
         switch (event.key.keysym.sym) 
         {
         case SDLK_ESCAPE:
            fprintf(stderr, "Hit Escape!n");
            return false;
            break;

         default:
            break;
         }
         break;

         //Called when the mouse moves
      case SDL_MOUSEMOTION:
         break;

      case SDL_KEYUP:
         printf( "Key release detected\n" );
         break;

      default:
         break;
      }
   }
   return true;
}

void Touch::UpdateDisplay()
{
   SDL_FillRect(m_pScreen, NULL, SDL_MapRGB(m_pScreen->format, 255, 255, 255));

   nSDL_DrawString(m_pScreen, m_pFont, 10, 10, "contact: %d", m_tpad_report.contact);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 30, "proximity: %d", m_tpad_report.proximity);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 50, "x: %d", m_tpad_report.x);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 70, "y: %d", m_tpad_report.y);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 90, "x_velocity: %d", m_tpad_report.x_velocity);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 110, "y_velocity: %d", m_tpad_report.y_velocity);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 130, "pressed: %d", m_tpad_report.pressed);
   nSDL_DrawString(m_pScreen, m_pFont, 10, 150, "arrow: %d", m_tpad_report.arrow);

   SDL_UpdateRect(m_pScreen, 0, 0, SCREEN_WIDTH, SCREEN_HEIGHT);
}



